==> alloy-ui-3.0.1.jar: META-INF/resources/webjars/alloy-ui/3.0.1/src/aui-toolbar/HISTORY.md <==
# AUI Toolbar

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-toolbar).

## @VERSION@

No registries yet.

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1594](https://issues.liferay.com/browse/AUI-1594) Make aui-toolbar accessible
* [AUI-1442](https://issues.liferay.com/browse/AUI-1442) First click on each toolbar button is ignored on touch devices
* [AUI-1284](https://issues.liferay.com/browse/AUI-1284) Use cssClass attribute from WidgetCssClass instead of separated attributes for CSS class names in Button
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1248](https://issues.liferay.com/browse/AUI-1248) Allow users to request buttons to not have the .btn-default class on Bootstrap 3
* [AUI-1232](https://issues.liferay.com/browse/AUI-1232) Fix vertical Toolbar border-radius on Bootstrap 3
* [AUI-1233](https://issues.liferay.com/browse/AUI-1233) Use .btn-toolbar instead of .toolbar as container class on Bootstrap 3
* [AUI-1220](https://issues.liferay.com/browse/AUI-1220) Add .btn-default to .btn elements with no other color on Bootstrap 3
* [AUI-1223](https://issues.liferay.com/browse/AUI-1223) Use <span> instead of <i> when creating icons on Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants

==> alloy-ui-3.0.2.jar: META-INF/resources/webjars/alloy-ui/3.0.2/src/aui-toolbar/HISTORY.md <==
# AUI Toolbar

> Documentation and test modifications are not included in this changelog. For more details, see [full commit history](https://github.com/liferay/alloy-ui/commits/master/src/aui-toolbar).

## @VERSION@

* [AUI-2034](https://issues.liferay.com/browse/AUI-2034) Allow users to request buttons to not have the .btn and .btn-default classes from Bootstrap 3

No registries yet.

## [3.0.1](https://github.com/liferay/alloy-ui/releases/tag/3.0.1)

No changes.

## [3.0.0](https://github.com/liferay/alloy-ui/releases/tag/3.0.0)

* [AUI-1594](https://issues.liferay.com/browse/AUI-1594) Make aui-toolbar accessible
* [AUI-1442](https://issues.liferay.com/browse/AUI-1442) First click on each toolbar button is ignored on touch devices
* [AUI-1284](https://issues.liferay.com/browse/AUI-1284) Use cssClass attribute from WidgetCssClass instead of separated attributes for CSS class names in Button
* [AUI-1098](https://issues.liferay.com/browse/AUI-1098) Upgrade to Bootstrap 3
* [AUI-1248](https://issues.liferay.com/browse/AUI-1248) Allow users to request buttons to not have the .btn-default class on Bootstrap 3
* [AUI-1232](https://issues.liferay.com/browse/AUI-1232) Fix vertical Toolbar border-radius on Bootstrap 3
* [AUI-1233](https://issues.liferay.com/browse/AUI-1233) Use .btn-toolbar instead of .toolbar as container class on Bootstrap 3
* [AUI-1220](https://issues.liferay.com/browse/AUI-1220) Add .btn-default to .btn elements with no other color on Bootstrap 3
* [AUI-1223](https://issues.liferay.com/browse/AUI-1223) Use <span> instead of <i> when creating icons on Bootstrap 3

## [2.5.0](https://github.com/liferay/alloy-ui/releases/tag/2.5.0)

* [AUI-1163](https://issues.liferay.com/browse/AUI-1163) Remove unnecessary constants
